WA Pipelines
============

A Django app to setup pipelines that allow
collecting data from various endpoints in
a parallel fashion and submitting them to
a destination endpoint

.. image:: pipelines.png
    :scale: 50 %
